@@ -1,8 +1,15 @@
-from .Population import Population, PredefinedPopulation, attribute_columns, method_columns
+from .Population import (
+    Population,
+    PredefinedPopulation,
+    attribute_columns,
+    method_columns,
+)
 from .Exoplanets import *
 from .TransitingExoplanets import *
-from .TOI import *
-from .TOISubsets import *
+
+# (the TOI downloaders need fixing)
+# from .TOI import *
+# from .TOISubsets import *
 from .SolarSystem import *
 from .TransitingExoplanetsSubsets import *
 from .summary import *
