@@ -1,11 +1,14 @@
 from .imports import *
 from .Population import Population
 
+
 class Custom(PredefinedPopulation):
     def __init__(self, listofdictionaries=None, **kwargs):
-        '''Initialize a population of KOIs, from the downloaded CSV.'''
-        Population.__init__(self, label='New',  listofdictionaries=listofdictionaries, **kwargs)
-        self.color='darkorange'
+        """Initialize a population of KOIs, from the downloaded CSV."""
+        Population.__init__(
+            self, label="New", listofdictionaries=listofdictionaries, **kwargs
+        )
+        self.color = "darkorange"
         self.zorder = 10
 
     def loadFromScratch(self, **kwargs):
@@ -17,10 +20,10 @@ class Custom(PredefinedPopulation):
     def load_raw(self, **kwargs):
         pass
 
-    def create_standard(self,  listofdictionaries=None, remake=False):
-        '''Load a standardized population table, attempting...
-            ...first from an .npy file (fast)
-            ...then from a text file.'''
+    def create_standard(self, listofdictionaries=None, remake=False):
+        """Load a standardized population table, attempting...
+        ...first from an .npy file (fast)
+        ...then from a text file."""
 
         d = listofdictionaries
 
