@@ -1,23 +1,31 @@
 from .Panel import *
 
-__all__ = ['BubblePanel']
+__all__ = ["BubblePanel"]
+
+default_size = plt.matplotlib.rcParams["lines.markersize"] ** 2
 
-default_size = plt.matplotlib.rcParams['lines.markersize']**2
 
 class BubblePanel(Panel):
-    '''
+    """
     BubblePanel is a general wrapper for making scatter plots
     where planets are represented as bubbles that can have
     informative sizes and/or colors.
-    '''
+    """
 
-    def __init__(self,
-                 xaxis=None,
-                 yaxis=None,
-                 size=None, size_normalization=None,
-                 color=None, cmap='plasma', vmin=None, vmax=None, color_normalization=None,
-                 **kw):
-        '''
+    def __init__(
+        self,
+        xaxis=None,
+        yaxis=None,
+        size=None,
+        size_normalization=None,
+        color=None,
+        cmap="plasma",
+        vmin=None,
+        vmax=None,
+        color_normalization=None,
+        **kw,
+    ):
+        """
         Initialize a plotting panel.
 
         Parameters
@@ -50,7 +58,7 @@ class BubblePanel(Panel):
             more fine-grained control over which axis
             gets which keyword, consider initializing
             those panels one-by-one.
-        '''
+        """
 
         # initialize the basics of the panel with the plottable axes
         Panel.__init__(self, xaxis=xaxis, yaxis=yaxis, **kw)
@@ -59,13 +67,17 @@ class BubblePanel(Panel):
         size = clean_axis(size)
         try:
             # try to make a variable size axis
-            self.plottable['size'] = size(panel=self, **kw)
-            default_size_normalization = self.plottable['size'].normalization
+            self.plottable["size"] = size(panel=self, **kw)
+            default_size_normalization = self.plottable["size"].size_normalization
+
         except TypeError:
             # otherwise, use a single size for all points
-            self.plottable['size'] = size
+            self.plottable["size"] = size
             default_size_normalization = 1
 
+        # self.plottable['x'].panel = self
+        # self.plottable['y'].panel = self
+
         # make sure a size normalization has been defined
         self.size_normalization = size_normalization or default_size_normalization
 
@@ -73,11 +85,11 @@ class BubblePanel(Panel):
         color = clean_axis(color)
         try:
             # try to make a variable color axis
-            self.plottable['color'] = color(panel=self, **kw)
-            default_lim = self.plottable['color'].lim
+            self.plottable["color"] = color(panel=self, **kw)
+            default_lim = self.plottable["color"].lim
         except TypeError:
             # otherwise, use a single color for all points
-            self.plottable['color'] = color
+            self.plottable["color"] = color
             default_lim = [None, None]
 
         # if an actual cmap was provided, use it
@@ -85,7 +97,7 @@ class BubblePanel(Panel):
             self.cmap = cmap
         # otherwise, treat the cmap as a string key
         else:
-            self.cmap = plt.matplotlib.cm.cmap_d[cmap]
+            self.cmap = plt.matplotlib.cm.get_cmap(cmap)
 
         # make sure the color map limits are set
         self.vmin = vmin or default_lim[0]
@@ -93,22 +105,23 @@ class BubblePanel(Panel):
 
         # if a custom normalization is used, reset vmin + vmax
         self.color_normalization = color_normalization
-        if isinstance(self.color_normalization,
-                      plt.matplotlib.colors.Normalize):
+        if isinstance(self.color_normalization, plt.matplotlib.colors.Normalize):
             # pull the normalization's min/max for information
             self.vmin = color_normalization.vmin
             self.vmax = color_normalization.vmax
 
         # apply (x,y) axis labels, scales, limits appropriately
-        for axis in 'xy':
-            for attribute in ['label', 'scale', 'lim']:
-                setattr(self,
-                        f'{axis}{attribute}',
-                        getattr(self.plottable[axis],
-                                attribute))
+        for axis in "xy":
+            for attribute in ["label", "scale", "lim"]:
+                setattr(
+                    self, f"{axis}{attribute}", getattr(self.plottable[axis], attribute)
+                )
+
+        # DEBUG
+        self.summarize()
 
     def get_sizes(self):
-        '''
+        """
         The sizes of the bubbles.
 
         Returns
@@ -116,24 +129,27 @@ class BubblePanel(Panel):
         s : an input for plt.scatter
             Either a single scalar, or an array with variable
             sizes for each bubble according to some quantity.
-        '''
+        """
 
+        # should we ignore any variable size instructions?
+        if self.pop.respond_to_size == False:
+            size = self.pop.plotkw.get("s", None)
         # if desired, set variable sizes
-        if isinstance(self.plottable['size'], PlottableAxis):
+        elif isinstance(self.plottable["size"], PlottableAxis):
             # get the raw values for the sizes
-            x = self.plottable['size'].value()
+            x = self.plottable["size"].value()
             # calculate the normalized size
-            size = default_size*x/self.size_normalization
+            size = default_size * x / self.size_normalization
         # otherwise, set a single size
         else:
             # get default, first from pop and then from panel
-            size = self.pop.plotkw.get('s', self.plottable['size'])
+            size = self.pop.plotkw.get("s", self.plottable["size"])
 
         # return a valid input to plt.scatter(s=...)
         return size
 
     def get_colors(self):
-        '''
+        """
         The colors of the bubbles.
 
         Returns
@@ -141,18 +157,18 @@ class BubblePanel(Panel):
         c : an input for plt.scatter
             Either a single color, or an array with variable
             colors for each bubble according to some quantity.
-        '''
+        """
 
         # should we ignore any variable color instructions?
-        if self.pop.ink == False:
+        if self.pop.respond_to_color == False:
             color = self.pop.color
         # should we use a variable color?
-        elif isinstance(self.plottable['color'], PlottableAxis):
+        elif isinstance(self.plottable["color"], PlottableAxis):
             # get the raw values to go into the color
-            x = self.plottable['color'].value()
+            x = self.plottable["color"].value()
 
             # FIXME - make sure to check vmin/vmax are valid
-            #if (self.vmin is None) or (self.vmax is None):
+            # if (self.vmin is None) or (self.vmax is None):
             #    raise AtlasError(f'''
             #    It looks like you're trying to use
             #    {self.plottable['color']} to set variable
@@ -163,8 +179,9 @@ class BubblePanel(Panel):
 
             # make sure we have *some* normalizer defined
             f = plt.matplotlib.colors.Normalize
-            self.color_normalization = (self.color_normalization
-                or f(vmin=self.vmin, vmax=self.vmax))
+            self.color_normalization = self.color_normalization or f(
+                vmin=self.vmin, vmax=self.vmax
+            )
 
             normalized = self.color_normalization(x)
             color = self.cmap(normalized)
@@ -173,7 +190,7 @@ class BubblePanel(Panel):
             # get default, first from pop and then from panel
             color = self.pop.color
             if color is None:
-                color = self.plottable['color']
+                color = self.plottable["color"]
 
         # return a valid input to any one of the following:
         #   plt.scatter(c=...)
@@ -182,7 +199,7 @@ class BubblePanel(Panel):
         return color
 
     def kw(self, key=None, **kwargs):
-        '''
+        """
         Do a little decision-making about the plotting keyword
         arguments, pulling defaults from each population where
         needed.
@@ -195,32 +212,34 @@ class BubblePanel(Panel):
         **kwargs : dict
             All other keywords will be directed toward
             overwriting individual population defaults.
-        '''
+        """
 
         # identify the population we're working with
         if key is None:
             key = self.key
-        else:
-            self.point_at(key)
+        # else:
+        self.point_at(key)
 
         # define some default keywords, which can be over-written
-        default = dict(s=self.get_sizes(),
-                       marker=self.pop.marker,
-                       linewidth=self.pop.linewidth,
-                       alpha=self.pop.alpha,
-                       zorder=self.pop.zorder,
-                       label=self.pop.label)
+        default = dict(
+            s=self.get_sizes(),
+            marker=self.pop.marker,
+            linewidth=self.pop.linewidth,
+            alpha=self.pop.alpha,
+            zorder=self.pop.zorder,
+            label=self.pop.label,
+        )
 
         # sort out whether faces and/or edges should get color
-        c=self.get_colors()
+        c = self.get_colors()
         if self.pop.filled:
-            default['facecolors'] = c
+            default["facecolors"] = c
         else:
-            default['facecolors'] = 'none'
+            default["facecolors"] = "none"
         if self.pop.outlined:
-            default['edgecolors'] = c
+            default["edgecolors"] = c
         else:
-            default['edgecolors'] = 'none'
+            default["edgecolors"] = "none"
 
         # if any other keywords are provided, overwrite these defaults
         for k, v in kwargs.items():
@@ -229,7 +248,7 @@ class BubblePanel(Panel):
         return default
 
     def plot(self, key, ax=None, labelkw={}, **kwargs):
-        '''
+        """
         Add the points for a particular population to this panel.
 
         Parameters
@@ -243,7 +262,7 @@ class BubblePanel(Panel):
             Keywords for labeling the planet names.
         **kwargs : dict
             Any extra keywords will be passed on to `scatter`
-        '''
+        """
 
         # focus attention on that population
         self.point_at(key)
@@ -255,7 +274,7 @@ class BubblePanel(Panel):
             self.setup(ax=ax)
 
         # add the scattered points
-        self.scattered[key] = self.ax.scatter(self.x, self.y, **self.kw(key,**kwargs))
+        self.scattered[key] = self.ax.scatter(self.x, self.y, **self.kw(key, **kwargs))
 
         # set the scales, limits, labels
         self.finish_plot(labelkw=labelkw)
